---
name: Feature request
about: Suggest an idea for this project
title: 'ENH: '
labels: 'enhancement'
assignees: ''
---

Requested feature
=================
A short description of what you are proposing.

The problem or gap this feature will address
--------------------------------------------
A clear and concise description of what the problem is. For example, I'm always
frustrated when ...

The desired solution
--------------------
A clear and concise description of what you want to happen.  Keep the scope as
narrow as possible, to make it easier to implement

Possible alternatives
---------------------
A clear and concise description of any alternative solutions or features you've
considered.

Additional context
------------------
Add any other context or screenshots about the feature request here.  For
context, the apexpy version/branch you're working on, your system detail, your
python version, and your compiler (with version) may or may not be relevant.

Reminders
---------
This is a volunteer-driven project.  Code contributions are welcome, as is help
testing new code.
